# VariableResourceScope

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**project** | **list[str]** |  | [optional] 
**environment** | **list[str]** |  | [optional] 
**machine** | **list[str]** |  | [optional] 
**role** | **list[str]** |  | [optional] 
**target_role** | **list[str]** |  | [optional] 
**action** | **list[str]** |  | [optional] 
**user** | **list[str]** |  | [optional] 
**trigger** | **list[str]** |  | [optional] 
**parent_deployment** | **list[str]** |  | [optional] 
**private** | **list[str]** |  | [optional] 
**channel** | **list[str]** |  | [optional] 
**tenant_tag** | **list[str]** |  | [optional] 
**tenant** | **list[str]** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


